@@ -2,12 +2,12 @@ package Data::Session::ID::SHA512;
 
 use parent 'Data::Session::SHA';
 no autovivification;
-use common::sense;
-use warnings 'uninitialized';
+use strict;
+use warnings;
 
 use Hash::FieldHash ':all';
 
-our $VERSION = '1.03';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
