@@ -2,14 +2,14 @@ package Data::Session::ID::UUID36;
 
 use parent 'Data::Session::ID';
 no autovivification;
-use common::sense;
-use warnings 'uninitialized';
+use strict;
+use warnings;
 
 use Data::UUID;
 
 use Hash::FieldHash ':all';
 
-our $VERSION = '1.03';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
